/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-02 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.menus;

import java.io.IOException;
import java.io.Writer;
import java.util.Set;
import com.silverwrist.venice.ui.RequestOutput;

class SeparatorItem implements MenuComponent
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static SeparatorItem the_blank = new SeparatorItem(null);

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private MenuComponent subitem;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  SeparatorItem(MenuComponent subitem)
  {
    this.subitem = subitem;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface MenuComponent
   *--------------------------------------------------------------------------------
   */

  public void render(RequestOutput out, Writer wr) throws IOException
  {
    this.render(out,wr,java.util.Collections.EMPTY_SET);

  } // end render

  public void render(RequestOutput out, Writer wr, Set defines) throws IOException
  {
    if (subitem!=null)
      subitem.render(out,wr,defines);
    if (wr==null)
      wr = out.getWriter();
    wr.write("<BR>\n");

  } // end render

  public void renderOnLeft(RequestOutput out, Writer wr) throws IOException
  {
    this.renderOnLeft(out,wr,java.util.Collections.EMPTY_SET);

  } // end renderOnLeft

  public void renderOnLeft(RequestOutput out, Writer wr, Set defines) throws IOException
  {
    if (subitem!=null)
      subitem.renderOnLeft(out,wr,defines);
    if (wr==null)
      wr = out.getWriter();
    wr.write("<BR>\n");

  } // end renderHere

  public String getTitle(RequestOutput out)
  {
    return null;

  } // end getTitle

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  static SeparatorItem getBlank()
  {
    return the_blank;

  } // end getBlank

} // end class SeparatorItem
